@@ -14,6 +14,10 @@ import string
 
 import ldap
 
+import sys
+
+sys.getrecursionlimit(10000)
+
 __all__ = ["Position", "Department", "SystemAccount", "User", "App", "AppGroup"]
 
 
